@@ -1,7 +1,6 @@
 ;;; howm-common.el --- Wiki-like note-taking tool
-;;; Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2015, 2016
-;;;   HIRAOKA Kazuyuki <khi@users.sourceforge.jp>
-;;; $Id: howm-common.el,v 1.90 2012-12-29 08:57:18 hira Exp $
+;;; Copyright (C) 2002, 2003, 2004, 2005-2019
+;;;   HIRAOKA Kazuyuki <khi@users.osdn.me>
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -385,11 +384,11 @@ returns ((\"a\" \"aaa\" \"abc\") (\"x\" \"xyz\"))."
     (apply #'message `(,str ,@args))))
 
 (defun howm-decode-time (&optional specified-time)
-  "Decode SPECIFIED-TIME and remove DOW, DST, ZONE.
+  "Decode SPECIFIED-TIME and remove DOW, DST, ZONE, SUBSEC.
 When we do something like (encode-time (decode-time)), we use this function
 instead of the original `decode-time', so that we can force
 current timezone rule uniformly to avoid inconsistency."
-  (butlast (decode-time specified-time) 3))
+  (howm-first-n (decode-time specified-time) 6))
 
 (defmacro howm-with-need (&rest body)
   "Execute BODY where (need xxx) exits from this form if xxx is nil."
