@@ -1,7 +1,6 @@
 ;;; howm-vars.el --- Wiki-like note-taking tool
-;;; Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2015, 2016
-;;;   HIRAOKA Kazuyuki <khi@users.sourceforge.jp>
-;;; $Id: howm-vars.el,v 1.59 2011-12-31 15:07:29 hira Exp $
+;;; Copyright (C) 2005-2019
+;;;   HIRAOKA Kazuyuki <khi@users.osdn.me>
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -240,13 +239,21 @@ A file is excluded iff this regexp matches with all the relative paths."
   :group 'howm)
 
 (defcustom howm-menu-lang
-  (if (or (and (boundp 'current-language-environment)
-               (string= current-language-environment "Japanese"))
-          (string-match "^ja" (howm-get-locale)))
-      'ja
-    'en)
+  (let ((lang-table '((fr "French" "^fr")
+                      (ja "Japanese" "^ja"))))
+    (let ((lang (or (and (boundp 'current-language-environment)
+                        current-language-environment)
+                   ""))
+          (locale (howm-get-locale))
+          (ret 'en))
+      (mapc (lambda (rule)
+              (if (or (string= lang (cadr rule))
+                      (string-match (cl-caddr rule) locale))
+                  (setq ret (car rule))))
+            lang-table)
+      ret))
   "*Language of menu."
-  :type '(radio (const en) (const ja))
+  :type '(radio (const en) (const fr) (const ja))
   :group 'howm-menu)
 
 (howm-defcustom-risky howm-menu-file nil
